@@ -48,7 +48,7 @@ use Unicode::LineBreak qw(:all);
 ### Globals
 
 ### The package Version
-our $VERSION = '2011.03';
+our $VERSION = '2011.0';
 
 ### Public Configuration Attributes
 our $Config = {
@@ -68,19 +68,19 @@ my %FORMAT_FUNCS = (
 	my $str = shift;
 	if ($action =~ /^so[tp]/) {
 	    $self->{_} = {};
-	    $self->{_}->{'ColMax'} = $self->config('ColMax');
-	    $self->config('ColMax' => 0) if $str =~ /^>/;
+	    $self->{_}->{'ColumnsMax'} = $self->config('ColumnsMax');
+	    $self->config('ColumnsMax' => 0) if $str =~ /^>/;
 	} elsif ($action eq "") {
 	    $self->{_}->{line} = $str;
 	} elsif ($action eq "eol") {
 	    return $self->config('Newline');
 	} elsif ($action =~ /^eo/) {
-	    if (length $self->{_}->{line} and $self->config('ColMax')) {
+	    if (length $self->{_}->{line} and $self->config('ColumnsMax')) {
 		$str = $self->config('Newline').$self->config('Newline');
 	    } else {
 		$str = $self->config('Newline');
 	    }
-	    $self->config('ColMax' => $self->{_}->{'ColMax'});
+	    $self->config('ColumnsMax' => $self->{_}->{'ColumnsMax'});
 	    delete $self->{_};
 	    return $str;
 	}
@@ -187,30 +187,26 @@ Default is the value of Charset option.
 =item TabSize => NUMBER
 
 Column width of tab stops.
-When 0 is specified, tab stops are ignored.
+When 0 is specified, horizontal tab characters are ignored.
 Default is 8.
 
-=item BreakIndent
+=item CharactersMax
 
-=item CharMax
+=item ColumnsMin
 
-=item ColMax
-
-=item ColMin
-
-=item ComplexBreaking
-
-=item EAWidth
+=item ColumnsMax
 
 =item HangulAsAL
 
-=item LBClass
-
 =item LegacyCM
 
-=item Prep
+=item TailorEA
 
-=item Urgent
+=item TailorLB
+
+=item UrgentBreaking
+
+=item UserBreaking
 
 See L<Unicode::LineBreak/Options>.
 
@@ -274,7 +270,7 @@ sub config {
     ## Set sizing method.
     ## Note: Example in Unicode::LineBreak POD treats $spcstr as Perl string.
     ## Following code is more efficient.
-    $self->SUPER::config(Sizing => sub {
+    $self->SUPER::config(SizingMethod => sub {
 	my ($self, $cols, $pre, $spc, $str) = @_;
 
 	my $tabsize = $self->{TabSize};
@@ -292,7 +288,8 @@ sub config {
     });
 
     ## Classify horizontal tab as line breaking class SP.
-    $self->SUPER::config(LBClass => [ord("\t") => LB_SP]);
+    my @tailor_lb = @{$self->SUPER::config('TailorLB')};
+    $self->SUPER::config(TailorLB => [@tailor_lb, ord("\t") => LB_SP]);
     ## Tab size
     if (defined $self->{TabSize}) {
 	croak "Invalid TabSize option" unless $self->{TabSize} =~ /^\d+$/;
@@ -598,7 +595,7 @@ L<Unicode::LineBreak>, L<Text::Wrap>.
 
 =head1 AUTHOR
 
-Copyright (C) 2009-2011 Hatuka*nezumi - IKEDA Soji <hatuka(at)nezumi.nu>.
+Copyright (C) 2009 Hatuka*nezumi - IKEDA Soji <hatuka(at)nezumi.nu>.
 
 This program is free software; you can redistribute it and/or modify it 
 under the same terms as Perl itself.
